@@ -1,5 +1,5 @@
-#  tests for terminado-0.9.4-py39hcbf5309_0 (this is a generated file);
-print('===== testing package: terminado-0.9.4-py39hcbf5309_0 =====');
+#  tests for terminado-0.12.0-py39hcbf5309_0 (this is a generated file);
+print('===== testing package: terminado-0.12.0-py39hcbf5309_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """ run terminado tests with pytest, including platform- and python-based skips
@@ -26,15 +26,17 @@ skips = []
 
 # flaky tests
 if platform != "linux":
-    skips += ["max_terminals", "single_process", "namespace", "basic_command"]
-
-if platform == "darwin":
-    skips += ["unique_processes"]
+    skips += [
+        "basic_command",
+        "max_terminals",
+        "namespace",
+        "single_process",
+        "unique_processes"
+    ]
 
 if "aarch64" in target_platform:
     skips += ["max_terminals"]
 
-
 if not skips:
     print("all tests will be run", flush=True)
 
@@ -50,7 +52,7 @@ print(" ".join([*pytest, *pytest_args]), flush=True)
 sys.exit(subprocess.call([*pytest, *pytest_args]))
 #  --- run_test.py (end) ---
 
-print('===== terminado-0.9.4-py39hcbf5309_0 OK =====');
+print('===== terminado-0.12.0-py39hcbf5309_0 OK =====');
 print("import: 'terminado'")
 import terminado
 
